Documentation
¶
Overview ¶
Package pp implements Scheme pretty-printing.
Index ¶
- type HTML
- func (w *HTML) Debug()
- func (w *HTML) Error() error
- func (w *HTML) Header()
- func (w *HTML) Keyword(keyword string)
- func (w *HTML) Literal(lit string)
- func (w *HTML) Name(name string)
- func (w *HTML) Pop()
- func (w *HTML) Printf(format string, a ...any)
- func (w *HTML) Println(a ...any)
- func (w *HTML) Push()
- func (w *HTML) PushN(n int)
- func (w *HTML) Trailer()
- func (w *HTML) Type(t string)
- type Writer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HTML ¶
type HTML struct {
// contains filtered or unexported fields
}
HTML implements HTML pretty-printing.
type Writer ¶
type Writer interface {
// Debug prints debugging information about the Writer.
Debug()
// Header creates the output header. This is called at the
// beginning of the pretty-print.
Header()
// Trailer creates the output trailer. This is called at the end
// of the pretty-print.
Trailer()
// Push pushes the current column as new left margin.
Push()
// Pop removes the current left margin and sets the previous left
// margin as the current one.
Pop()
// PushN adjust the left margin with n columns.
PushN(n int)
// Println formats using the default formats for its operands and
// outputs the result. Spaces are always added between operands
// and a newline is appended.
Println(a ...any)
// Printf prints a formatted message.
Printf(format string, a ...any)
// Keyword prints a Scheme keyword.
Keyword(keyword string)
// Name prints a Scheme name.
Name(name string)
// Type prints a type.
Type(t string)
// Literal prints a string literal.
Literal(t string)
// Error returns an error if any of the methods failed during the
// pretty-printing.
Error() error
}
Writer implements Scheme pretty-printer.
Click to show internal directories.
Click to hide internal directories.